@@ -57,8 +57,8 @@ def create_workflow(submission_uuid, steps, on_init_params=None):
     def sub_err_msg(specific_err_msg):
         """ Submission error message"""
         return (
-            u"Could not create assessment workflow: "
-            u"retrieving submission {} failed: {}"
+            "Could not create assessment workflow: "
+            "retrieving submission {} failed: {}"
             .format(submission_uuid, specific_err_msg)
         )
 
@@ -68,35 +68,35 @@ def create_workflow(submission_uuid, steps, on_init_params=None):
     try:
         workflow = AssessmentWorkflow.start_workflow(submission_uuid, steps, on_init_params)
         logger.info((
-            u"Started assessment workflow for "
-            u"submission UUID {uuid} with steps {steps}"
+            "Started assessment workflow for "
+            "submission UUID {uuid} with steps {steps}"
         ).format(uuid=submission_uuid, steps=steps))
         return AssessmentWorkflowSerializer(workflow).data
-    except sub_api.SubmissionNotFoundError:
+    except sub_api.SubmissionNotFoundError as ex:
         err_msg = sub_err_msg("submission not found")
         logger.error(err_msg)
-        raise AssessmentWorkflowRequestError(err_msg)
+        raise AssessmentWorkflowRequestError(err_msg) from ex
     except sub_api.SubmissionRequestError as err:
         err_msg = sub_err_msg(err)
         logger.error(err_msg)
-        raise AssessmentWorkflowRequestError(err_msg)
+        raise AssessmentWorkflowRequestError(err_msg) from err
     except sub_api.SubmissionInternalError as err:
         logger.error(err)
         raise AssessmentWorkflowInternalError(
-            u"retrieving submission {} failed with unknown error: {}"
+            "retrieving submission {} failed with unknown error: {}"
             .format(submission_uuid, err)
-        )
-    except DatabaseError:
-        err_msg = u"Could not create assessment workflow for submission UUID: {}".format(submission_uuid)
+        ) from err
+    except DatabaseError as ex:
+        err_msg = f"Could not create assessment workflow for submission UUID: {submission_uuid}"
         logger.exception(err_msg)
-        raise AssessmentWorkflowInternalError(err_msg)
-    except Exception:
+        raise AssessmentWorkflowInternalError(err_msg) from ex
+    except Exception as ex:
         err_msg = (
-            u"An unexpected error occurred while creating "
-            u"the workflow for submission UUID {}"
+            "An unexpected error occurred while creating "
+            "the workflow for submission UUID {}"
         ).format(submission_uuid)
         logger.exception(err_msg)
-        raise AssessmentWorkflowInternalError(err_msg)
+        raise AssessmentWorkflowInternalError(err_msg) from ex
 
 
 def get_workflow_for_submission(submission_uuid, assessment_requirements):
@@ -197,11 +197,18 @@ def update_from_assessments(submission_uuid, assessment_requirements, override_s
             relationship between submissions and workflows, so this uniquely
             identifies the `AssessmentWorkflow`.
         assessment_requirements (dict): Dictionary that currently looks like:
-            `{"peer": {"must_grade": <int>, "must_be_graded_by": <int>}}`
+            `{"peer": {
+                 "must_grade": <int>,
+                 "must_be_graded_by": <int>,
+                 "enable_flexible_grading": <bool>
+            }}`
             `must_grade` is the number of assessments a student must complete.
             `must_be_graded_by` is the number of assessments a submission must
             receive to be scored. `must_grade` should be greater than
             `must_be_graded_by` to ensure that everyone will get scored.
+            `enable_flexible_grading` loosens the number of required peer
+            assessments to `floor(0.7 * must_be_graded_by)` in case the
+            submission is more than 7 days old
             The intention is to eventually pass in more assessment sequence
             specific requirements in this dict.
         override_submitter_requirements (bool): If True, the presence of a new
@@ -264,14 +271,14 @@ def update_from_assessments(submission_uuid, assessment_requirements, override_s
     try:
         workflow.update_from_assessments(assessment_requirements, override_submitter_requirements)
         logger.info((
-            u"Updated workflow for submission UUID {uuid} "
-            u"with requirements {reqs}"
+            "Updated workflow for submission UUID {uuid} "
+            "with requirements {reqs}"
         ).format(uuid=submission_uuid, reqs=assessment_requirements))
         return _serialized_with_details(workflow)
     except PeerAssessmentError as err:
-        err_msg = u"Could not update assessment workflow: {}".format(err)
+        err_msg = f"Could not update assessment workflow: {err}"
         logger.exception(err_msg)
-        raise AssessmentWorkflowInternalError(err_msg)
+        raise AssessmentWorkflowInternalError(err_msg) from err
 
 
 def get_status_counts(course_id, item_id, steps):
@@ -348,19 +355,19 @@ def _get_workflow_model(submission_uuid):
     try:
         workflow = AssessmentWorkflow.get_by_submission_uuid(submission_uuid)
     except AssessmentWorkflowError as exc:
-        raise AssessmentWorkflowInternalError(repr(exc))
+        raise AssessmentWorkflowInternalError(repr(exc)) from exc
     except Exception as exc:
         # Something very unexpected has just happened (like DB misconfig)
         err_msg = (
-            u"Could not get assessment workflow with submission_uuid {} due to error: {}"
+            "Could not get assessment workflow with submission_uuid {} due to error: {}"
             .format(submission_uuid, exc)
         )
         logger.exception(err_msg)
-        raise AssessmentWorkflowInternalError(err_msg)
+        raise AssessmentWorkflowInternalError(err_msg) from exc
 
     if workflow is None:
         raise AssessmentWorkflowNotFoundError(
-            u"No assessment workflow matching submission_uuid {}".format(submission_uuid)
+            f"No assessment workflow matching submission_uuid {submission_uuid}"
         )
 
     return workflow
@@ -408,11 +415,11 @@ def get_assessment_workflow_cancellation(submission_uuid):
     try:
         workflow_cancellation = AssessmentWorkflowCancellation.get_latest_workflow_cancellation(submission_uuid)
         return AssessmentWorkflowCancellationSerializer(workflow_cancellation).data if workflow_cancellation else None
-    except DatabaseError:
-        error_message = u"Error finding assessment workflow cancellation for submission UUID {}."\
+    except DatabaseError as ex:
+        error_message = "Error finding assessment workflow cancellation for submission UUID {}."\
             .format(submission_uuid)
         logger.exception(error_message)
-        raise PeerAssessmentInternalError(error_message)
+        raise PeerAssessmentInternalError(error_message) from ex
 
 
 def is_workflow_cancelled(submission_uuid):
