@@ -10,6 +10,8 @@ import MessageView from './oa_message';
 import StaffAreaView from './oa_staff_area';
 import StudentTrainingView from './oa_training';
 import PeerView from './oa_peer';
+import ResponseEditorLoader from './oa_response_editor';
+
 /**
 Interface for student-facing views.
 
@@ -41,10 +43,14 @@ export class BaseView {
       this.server = server;
       this.fileUploader = new FileUploader();
 
-      this.responseView = new ResponseView(this.element, this.server, this.fileUploader, this, data);
-      this.trainingView = new StudentTrainingView(this.element, this.server, this);
-      this.selfView = new SelfView(this.element, this.server, this);
-      this.peerView = new PeerView(this.element, this.server, this);
+      this.responseEditorLoader = new ResponseEditorLoader(data.AVAILABLE_EDITORS);
+
+      this.responseView = new ResponseView(
+        this.element, this.server, this.fileUploader, this.responseEditorLoader, this, data,
+      );
+      this.trainingView = new StudentTrainingView(this.element, this.server, this.responseEditorLoader, data, this);
+      this.selfView = new SelfView(this.element, this.server, this.responseEditorLoader, data, this);
+      this.peerView = new PeerView(this.element, this.server, this.responseEditorLoader, data, this);
       this.staffView = new StaffView(this.element, this.server, this);
       this.gradeView = new GradeView(this.element, this.server, this);
       this.leaderboardView = new LeaderboardView(this.element, this.server, this);
