@@ -29,13 +29,15 @@ export class ResponseView {
 
     UNSAVED_WARNING_KEY = 'learner-response';
 
-    constructor(element, server, fileUploader, baseView, data) {
+    constructor(element, server, fileUploader, responseEditorLoader, baseView, data) {
       this.element = element;
       this.server = server;
       this.fileUploader = fileUploader;
+      this.responseEditorLoader = responseEditorLoader;
       this.baseView = baseView;
       this.savedResponse = [];
       this.textResponse = 'required';
+      this.textResponseEditor = 'text';
       this.fileUploadResponse = '';
       this.files = null;
       this.filesDescriptions = [];
@@ -66,19 +68,35 @@ export class ResponseView {
           // Load the HTML and install event handlers
           $(stepID, view.element).replaceWith(html);
           view.server.renderLatex($(stepID, view.element));
-          view.installHandlers();
-          view.setAutoSaveEnabled(true);
-          view.isRendering = false;
-          view.baseView.announceStatusChangeToSRandFocus(stepID, usageID, false, view, focusID);
-          view.announceStatus = false;
-          view.dateFactory.apply();
-          view.checkSubmissionAbility();
+
+          // First load response editor then apply other things
+          view.loadResponseEditor().then((editorController) => {
+            view.responseEditorController = editorController;
+            view.installHandlers();
+            view.setAutoSaveEnabled(true);
+            view.isRendering = false;
+            view.baseView.announceStatusChangeToSRandFocus(stepID, usageID, false, view, focusID);
+            view.announceStatus = false;
+            view.dateFactory.apply();
+            view.checkSubmissionAbility();
+          });
         },
       ).fail(() => {
         view.baseView.showLoadError('response');
       });
     }
 
+    /**
+     * Load currently selected editor.
+     *
+     * Returns: promise
+     */
+    loadResponseEditor() {
+      const sel = $('.step--response', this.element);
+      const editorElements = sel.find('.submission__answer__part__text__value');
+      return this.responseEditorLoader.load(this.data.TEXT_RESPONSE_EDITOR, editorElements);
+    }
+
     /**
      Install event handlers for the view.
      * */
@@ -92,10 +110,9 @@ export class ResponseView {
       // Install a click handler for collapse/expand
       this.baseView.setUpCollapseExpand(sel);
 
-      // Install change handler for textarea (to enable submission button)
+      // Install change handler for editor (to enable submission button)
       this.savedResponse = this.response();
-      const handleChange = function () { view.handleResponseChanged(); };
-      sel.find('.submission__answer__part__text__value').on('change keyup drop paste', handleChange);
+      this.responseEditorController.setOnChangeListener(this.handleResponseChanged.bind(this));
 
       const handlePrepareUpload = function (eventData) { view.prepareUpload(eventData.target.files, uploadType); };
       sel.find('input[type=file]').on('change', handlePrepareUpload);
@@ -356,15 +373,7 @@ export class ResponseView {
      * */
     /* eslint-disable-next-line consistent-return */
     response(texts) {
-      const sel = $('.response__submission .submission__answer__part__text__value', this.element);
-      if (typeof texts === 'undefined') {
-        return sel.map(function () {
-          return $.trim($(this).val());
-        }).get();
-      }
-      sel.each(function (index) {
-        $(this).val(texts[index]);
-      });
+      return this.responseEditorController.response(texts);
     }
 
     /**
